/*
	*
	* This file is a part of CoreKeyboard.
	* An on-screenkeyboard for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, see {http://www.gnu.org/licenses/}.
	*
*/

#pragma once

#include <QWidget>
#include <QMenu>
#include <QCoreApplication>
#include <QSystemTrayIcon>

#include <cprime/settingsmanage.h>

class trayicon : public QSystemTrayIcon {

    Q_OBJECT

public:
    trayicon( QWidget *parent ) : QSystemTrayIcon( parent ) {

        setIcon( QIcon::fromTheme("corekeyboard" ) );
        show();

        connect( this, SIGNAL( activated( QSystemTrayIcon::ActivationReason ) ), this, SLOT( activationHandler( QSystemTrayIcon::ActivationReason ) ) );

		QMenu *menu = new QMenu( "TrayMenu" );

		menu->addAction( QIcon(), "&Toggle Visible", this, SIGNAL( toggleShowHide() ) );
		menu->addAction( QIcon::fromTheme( "application-quit" ), "&Quit CoreKeyboard", QCoreApplication::instance(), SLOT( quit() ) );
		setContextMenu( menu );
    }

private Q_SLOTS:
    void activationHandler( QSystemTrayIcon::ActivationReason reason ) {

        if ( reason == QSystemTrayIcon::Trigger ) {
			if ( settingsManage::initialize( true )->value( "CoreApps", "TouchMode" ) == true )
				contextMenu()->exec( QCursor::pos() );

			else
				emit toggleShowHide();
		}
    }

Q_SIGNALS:
    void toggleShowHide();
    void minimize();
};
